@@ -21,12 +21,15 @@ from navigator_session import SESSION_KEY, SessionHandler, get_session
 from .authorizations import authz_allow_hosts, authz_hosts
 from .backends.abstract import decode_token
 from .conf import (
+    AUTH_CREDENTIALS_REQUIRED,
     AUTH_USER_MODEL,
     AUTHENTICATION_BACKENDS,
     AUTHORIZATION_BACKENDS,
     AUTHORIZATION_MIDDLEWARES,
     default_dsn,
+    REDIS_AUTH_URL,
     logging,
+    exclude_list
 )
 from .exceptions import (
     AuthException,
@@ -41,16 +44,8 @@ from .handlers import handler_routes
 ## Responses
 from .responses import JSONResponse
 from .storages.postgres import PostgresStorage
+from .storages.redis import RedisStorage
 
-exclude_list = (
-    "/static/",
-    "/api/v1/login",
-    "/api/v1/logout",
-    "/login",
-    "/logout",
-    "/signin",
-    "/signout",
-)
 
 class AuthHandler:
     """Authentication Backend for Navigator."""
@@ -95,6 +90,10 @@ class AuthHandler:
         # TODO: Session Support with parametrization (other backends):
         self._session = SessionHandler(storage='redis', use_cookie=True) # pylint: disable=E1123
 
+    @property
+    def session(self):
+        return self._session
+
     async def auth_startup(self, app):
         """
         Some Authentication backends need to call an Startup.
@@ -224,6 +223,10 @@ class AuthHandler:
                     raise web.HTTPForbidden(
                         reason='User was not authenticated'
                     )
+            except UserNotFound as err:
+                raise web.HTTPForbidden(
+                    reason=f"{err.message}"
+                )
             except (Forbidden, FailedAuth) as err:
                 raise web.HTTPForbidden(
                     reason=f"{err.message}"
@@ -238,7 +241,7 @@ class AuthHandler:
                     reason=f"User Doesn't exists: {err.message}"
                 )
             except Exception as err:
-                raise web.HTTPClientError(
+                raise web.HTTPInternalServerError(
                     reason=f"{err.message}"
                 )
         else:
@@ -363,6 +366,14 @@ class AuthHandler:
         # configuring Session Object
         self._session.setup(self.app)
         ## Manager for Auth Storage and Policy Storage
+        ## adding a Redis Connection:
+        try:
+            redis = RedisStorage(driver='redis', dsn=REDIS_AUTH_URL)
+            redis.configure(self.app) # pylint: disable=E1123
+        except RuntimeError as ex:
+            raise web.HTTPServerError(
+                reason=f"Error creating Redis connection: {ex}"
+            )
         ## getting Database Connection:
         try:
             pool = PostgresStorage(driver='pg', dsn=default_dsn)
@@ -437,6 +448,7 @@ class AuthHandler:
                 ) from err
         # last: add the basic jwt middleware (used by basic auth and others)
         mdl.append(self.auth_middleware)
+
         # at the End: configure CORS for routes:
         cors = aiohttp_cors.setup(
             self.app,
@@ -453,6 +465,18 @@ class AuthHandler:
         self.setup_cors(cors)
         return self.app
 
+    async def get_session_user(self, session: Iterable, name: str = 'user') -> Iterable:
+        try:
+            if session:
+                user = session.decode(name)
+                if user:
+                    user.is_authenticated = True
+                return user
+        except (AttributeError, RuntimeError) as ex:
+            logging.warning(
+                f'NAV: Unable to decode User session: {ex}'
+            )
+
     async def auth_middleware(
         self,
         app: web.Application,
@@ -464,7 +488,6 @@ class AuthHandler:
         """
         @web.middleware
         async def middleware(request: web.Request) -> web.StreamResponse:
-            logging.debug(':: BASIC AUTH MIDDLEWARE ::')
             # avoid authorization backend on excluded methods:
             if request.method == hdrs.METH_OPTIONS:
                 return await handler(request)
@@ -487,27 +510,34 @@ class AuthHandler:
                     return await handler(request)
             except KeyError:
                 pass
+            logging.debug(':: AUTH MIDDLEWARE ::')
             try:
                 _, payload = decode_token(request)
                 if payload:
                     ## check if user has a session:
                     # load session information
                     session = await get_session(request, payload, new = False)
-                    try:
-                        try:
-                            request.user = session.decode('user')
-                            if request.user:
-                                request.user.is_authenticated = True
-                        except (AttributeError, RuntimeError) as ex:
-                            logging.error(
-                                f'NAV: Unable to decode User session: {ex}'
+                    if not session:
+                        if AUTH_CREDENTIALS_REQUIRED is True:
+                            raise web.HTTPUnauthorized(
+                                reason="There is no Session for User or Authentication is missing"
                             )
-                            # Error decoding user session, try to create them instead
+                    try:
+                        request.user = await self.get_session_user(session)
                         request['authenticated'] = True
                     except Exception as ex: # pylint: disable=W0703
                         logging.error(
                             f'Missing User Object from Session: {ex}'
                         )
+                elif self.secure_cookies is True:
+                    session = await get_session(request, None, new = False)
+                    if not session:
+                        if AUTH_CREDENTIALS_REQUIRED is True:
+                            raise web.HTTPUnauthorized(
+                                reason="There is no Session for User or Authentication is missing"
+                            )
+                    request.user = await self.get_session_user(session)
+                    request['authenticated'] = True
             except (Forbidden) as err:
                 logging.error('Auth Middleware: Access Denied')
                 raise web.HTTPUnauthorized(
@@ -525,8 +555,9 @@ class AuthHandler:
                 )
             except Exception as err: # pylint: disable=W0703
                 logging.error(f"Bad Request: {err!s}")
-                raise web.HTTPBadRequest(
-                    reason=f"Auth Error: {err!s}"
-                )
+                if AUTH_CREDENTIALS_REQUIRED is True:
+                    raise web.HTTPBadRequest(
+                        reason=f"Auth Error: {err!s}"
+                    )
             return await handler(request)
         return middleware
