@@ -1,5 +1,5 @@
 import asyncio
-from collections.abc import Callable
+from collections.abc import Callable, Iterable
 from abc import ABC, abstractmethod
 from datetime import datetime, timedelta
 from functools import partial, wraps
@@ -29,7 +29,7 @@ from navigator_auth.conf import (
     AUTH_USERNAME_ATTRIBUTE,
     AUTH_JWT_ALGORITHM,
     USER_MAPPING,
-    CREDENTIALS_REQUIRED,
+    AUTH_CREDENTIALS_REQUIRED,
     SECRET_KEY
 )
 
@@ -60,7 +60,7 @@ class BaseAuthBackend(ABC):
         self._session = None
         self._app: web.Application = None # reference for Application
         # force using of credentials
-        self.credentials_required: bool = CREDENTIALS_REQUIRED
+        self.credentials_required: bool = AUTH_CREDENTIALS_REQUIRED
         self._credentials = None
         self.user_property = SESSION_USER_PROPERTY
         if user_attribute:
@@ -83,7 +83,7 @@ class BaseAuthBackend(ABC):
         # starts the Executor
         self.executor = ThreadPoolExecutor(max_workers=1)
         # logger
-        self.logger = logging.getLogger('Nav-auth.backends')
+        self.logger = logging.getLogger('Auth.backends')
 
     @classmethod
     def authz_backends(cls):
@@ -102,6 +102,7 @@ class BaseAuthBackend(ABC):
     async def get_user(self, **search):
         """Getting User Object."""
         user = None
+        error = None
         try:
             db = self._app['authdb']
             async with await db.acquire() as conn:
@@ -110,7 +111,9 @@ class BaseAuthBackend(ABC):
         except ValidationError as ex:
             self.logger.error(f"Invalid User Information {search!s}")
             print(ex.payload)
+            error = ex
         except Exception as e:
+            error = e
             self.logger.error(f"Error getting User {search!s}")
             raise UserNotFound(
                 f"Error getting User {search!s}: {e!s}"
@@ -118,7 +121,7 @@ class BaseAuthBackend(ABC):
         # if not exists, return error of missing
         if not user:
             raise UserNotFound(
-                f"User {search!s} doesn't exists"
+                f"User {search!s} doesn't exists: {error}"
             )
         return user
 
@@ -171,7 +174,10 @@ class BaseAuthBackend(ABC):
                 session = await new_session(request, userdata)
                 user.is_authenticated = True # if session, then, user is authenticated.
                 session[self.session_key_property] = identity
-                session['user'] = session.encode(user)
+                try:
+                    session['user'] = session.encode(user)
+                except RuntimeError:
+                    pass
                 request['session'] = session
             except Exception as err:
                 raise web.HTTPForbidden(
@@ -240,6 +246,18 @@ class BaseAuthBackend(ABC):
                 self.logger.exception(err)
         return _wrap
 
+    async def get_session_user(self, session: Iterable, name: str = 'user') -> Iterable:
+        try:
+            if session:
+                user = session.decode(name)
+                if user:
+                    user.is_authenticated = True
+            return user
+        except (AttributeError, RuntimeError) as ex:
+            logging.warning(
+                f'NAV: Unable to decode User session: {ex}'
+            )
+
 
 def decode_token(request, issuer: str = None):
     jwt_token = None
