@@ -10,6 +10,7 @@ from aiohttp.web_urldispatcher import SystemRoute
 from navigator_auth.libs.cipher import Cipher
 from navigator_auth.exceptions import AuthException, InvalidAuth
 from navigator_auth.conf import (
+    AUTH_CREDENTIALS_REQUIRED,
     AUTH_JWT_ALGORITHM,
     AUTH_TOKEN_ISSUER,
     AUTH_TOKEN_SECRET,
@@ -67,7 +68,7 @@ class APIKeyAuth(BaseAuthBackend):
                 mech = 'api'
             else:
                 return [None, None]
-        except Exception as err:
+        except Exception as err: # pylint: disable=W0703
             self.logger.exception(f"API Key Auth: Error getting payload: {err}")
             return None
         return [mech, token]
@@ -133,8 +134,10 @@ class APIKeyAuth(BaseAuthBackend):
                     "token": token,
                     **user
                 }
-            except Exception as err:
-                self.logger.exception(f'API Key Auth: Authentication Error: {err}')
+            except Exception as err: # pylint: disable=W0703
+                self.logger.exception(
+                    f'API Key Auth: Authentication Error: {err}'
+                )
                 return False
 
     async def check_token_info(self, request, mech, payload):
@@ -159,7 +162,7 @@ class APIKeyAuth(BaseAuthBackend):
                     return False
                 else:
                     return result
-        except Exception as err:
+        except Exception as err: # pylint: disable=W0703
             self.logger.exception(err)
             return False
 
@@ -168,7 +171,6 @@ class APIKeyAuth(BaseAuthBackend):
 
     async def auth_middleware(self, app, handler):
         async def middleware(request):
-            self.logger.debug(f'MIDDLEWARE: {self.__class__.__name__}')
             request.user = None
             # avoid check system routes
             try:
@@ -182,27 +184,30 @@ class APIKeyAuth(BaseAuthBackend):
                     return await handler(request)
             except KeyError:
                 pass
+            self.logger.debug(f'MIDDLEWARE: {self.__class__.__name__}')
             try:
                 userdata = await self.authenticate(request)
-                if not userdata:
-                    # API Key missing, maybe auth with another mechanism?
-                    return await handler(request)
-                request['authenticated'] = True
-                request[self.session_key_property] = userdata['user_id']
+                if userdata:
+                    request['authenticated'] = True
+                    request[self.session_key_property] = userdata['user_id']
             except (InvalidAuth) as err:
                 raise web.HTTPForbidden(
                     reason=f"API Key: {err.message!s}"
                 )
             except AuthException as err:
-                self.logger.error(f"Invalid authorization token: {err!r}")
-                raise web.HTTPForbidden(
-                    reason=f"API Key: Invalid authorization Key: {err!r}"
-                )
+                if AUTH_CREDENTIALS_REQUIRED is True:
+                    self.logger.error(
+                        f"Invalid authorization token: {err!r}"
+                    )
+                    raise web.HTTPForbidden(
+                        reason=f"API Key: Invalid authorization Key: {err!r}"
+                    )
             except Exception as err:
-                self.logger.exception(f"Error on Token Middleware: {err}")
-                raise web.HTTPBadRequest(
-                    reason=f"Authentication Error: {err}"
-                )
+                if AUTH_CREDENTIALS_REQUIRED is True:
+                    self.logger.exception(f"Error on API Key Middleware: {err}")
+                    raise web.HTTPBadRequest(
+                        reason=f"API Auth Error: {err}"
+                    )
             return await handler(request)
 
         return middleware
