@@ -1,6 +1,9 @@
 from datetime import datetime
 from asyncdb.models import Column, Model
-
+from navigator_auth.conf import (
+    AUTH_DB_SCHEMA,
+    AUTH_USERS_VIEW
+)
 
 
 class User(Model):
@@ -23,18 +26,21 @@ class User(Model):
     avatar: str = Column(max=512)
     associate_id: str = Column(required=False)
     associate_oid: str = Column(required=False)
+    company: str = Column(required=False)
     department_code: str = Column(required=False)
+    department: str = Column(required=False)
     position_id: str = Column(required=False)
     group_id: list = Column(required=False)
     groups: list = Column(required=False)
-    program_id: list = Column(required=False)
+    # program_id: list = Column(required=False)
     programs: list = Column(required=False)
-    created_at: datetime = Column(required=False)
+    # created_at: datetime = Column(required=False)
+    date_joined: datetime = Column(required=False)
 
     class Meta:
         driver = "pg"
-        name = 'vw_users'
-        schema = "auth"
+        name = AUTH_USERS_VIEW
+        schema = AUTH_DB_SCHEMA
         strict = True
         frozen = False
         connection = None
