@@ -21,12 +21,12 @@ AUTHENTICATION_BACKENDS = (
  #'navigator.auth.backends.ADFSAuth',
  # 'navigator.auth.backends.AzureAuth',
  #'navigator.auth.backends.GithubAuth',
- #'navigator_auth.backends.APIKeyAuth',
- #'navigator_auth.backends.TokenAuth',
+ 'navigator_auth.backends.APIKeyAuth',
+ 'navigator_auth.backends.TokenAuth',
  'navigator_auth.backends.TrocToken',
- 'navigator_auth.backends.BasicAuth',
  'navigator_auth.backends.DjangoAuth',
- # 'navigator_auth.backends.NoAuth',
+ 'navigator_auth.backends.BasicAuth',
+ 'navigator_auth.backends.NoAuth',
 )
 
 ## AUTH_USER_MODEL: Model used for getting User Information
